@@ -13,6 +13,8 @@
 #include "configvalueprovider.h"
 #include "themepreviewer.h"
 
+class GSDXSettingsManager;
+
 class Q_DECL_EXPORT GtkConfig : public KDEDModule
 {
     Q_OBJECT
@@ -47,6 +49,7 @@ public Q_SLOTS:
 
     void onKdeglobalsSettingsChange(const KConfigGroup &group, const QByteArrayList &names) const;
     void onKWinSettingsChange(const KConfigGroup &group, const QByteArrayList &names) const;
+    void onKCMFontsSettingsChange(const KConfigGroup &group, const QByteArrayList &names) const;
     void onKCMInputSettingsChange(const KConfigGroup &group, const QByteArrayList &names) const;
     void onBreezeSettingsChange(const KConfigGroup &group, const QByteArrayList &names) const;
 
@@ -55,6 +58,9 @@ private:
     QScopedPointer<ThemePreviewer> themePreviewer;
     KConfigWatcher::Ptr kdeglobalsConfigWatcher;
     KConfigWatcher::Ptr kwinConfigWatcher;
+    KConfigWatcher::Ptr kcmfontsConfigWatcher;
     KConfigWatcher::Ptr kcminputConfigWatcher;
     KConfigWatcher::Ptr breezeConfigWatcher;
+
+    GSDXSettingsManager *m_gsdXsettingsManager = nullptr;
 };
